@@ -1,14 +1,17 @@
-#include "EventHandler.h"
-#include "Event.h"
-#include "Desc.h"
-#include "Func.h"
-#include "Scope.h"
-#include "NetVar.h"
-#include "ID.h"
-#include "Var.h"
+#include "zeek/EventHandler.h"
 
-#include "broker/Manager.h"
-#include "broker/Data.h"
+#include "zeek/Event.h"
+#include "zeek/Desc.h"
+#include "zeek/Func.h"
+#include "zeek/Scope.h"
+#include "zeek/NetVar.h"
+#include "zeek/ID.h"
+#include "zeek/Var.h"
+
+#include "zeek/broker/Manager.h"
+#include "zeek/broker/Data.h"
+
+namespace zeek {
 
 EventHandler::EventHandler(std::string arg_name)
 	{
@@ -26,31 +29,31 @@ EventHandler::operator bool() const
 			   || ! auto_publish.empty());
 	}
 
-const zeek::FuncTypePtr& EventHandler::GetType(bool check_export)
+const FuncTypePtr& EventHandler::GetType(bool check_export)
 	{
 	if ( type )
 		return type;
 
-	const auto& id = zeek::detail::lookup_ID(name.data(), zeek::detail::current_module.c_str(),
-	                                         false, false, check_export);
+	const auto& id = detail::lookup_ID(name.data(), detail::current_module.c_str(),
+	                                   false, false, check_export);
 
 	if ( ! id )
-		return zeek::FuncType::nil;
+		return FuncType::nil;
 
-	if ( id->GetType()->Tag() != zeek::TYPE_FUNC )
-		return zeek::FuncType::nil;
+	if ( id->GetType()->Tag() != TYPE_FUNC )
+		return FuncType::nil;
 
-	type = id->GetType<zeek::FuncType>();
+	type = id->GetType<FuncType>();
 	return type;
 	}
 
-void EventHandler::SetFunc(zeek::FuncPtr f)
+void EventHandler::SetFunc(FuncPtr f)
 	{ local = std::move(f); }
 
-void EventHandler::SetLocalHandler(zeek::Func* f)
-	{ SetFunc({zeek::NewRef{}, f}); }
+void EventHandler::SetLocalHandler(Func* f)
+	{ SetFunc({NewRef{}, f}); }
 
-void EventHandler::Call(zeek::Args* vl, bool no_remote)
+void EventHandler::Call(Args* vl, bool no_remote)
 	{
 #ifdef PROFILE_BRO_FUNCTIONS
 	DEBUG_MSG("Event: %s\n", Name());
@@ -70,7 +73,7 @@ void EventHandler::Call(zeek::Args* vl, bool no_remote)
 
 			for ( auto i = 0u; i < vl->size(); ++i )
 				{
-				auto opt_data = bro_broker::val_to_data((*vl)[i].get());
+				auto opt_data = Broker::detail::val_to_data((*vl)[i].get());
 
 				if ( opt_data )
 					xs.emplace_back(std::move(*opt_data));
@@ -107,7 +110,7 @@ void EventHandler::Call(zeek::Args* vl, bool no_remote)
 		local->Invoke(vl);
 	}
 
-void EventHandler::NewEvent(zeek::Args* vl)
+void EventHandler::NewEvent(Args* vl)
 	{
 	if ( ! new_event )
 		return;
@@ -116,11 +119,13 @@ void EventHandler::NewEvent(zeek::Args* vl)
 		// new_event() is the one event we don't want to report.
 		return;
 
-	auto vargs = zeek::MakeCallArgumentVector(*vl, GetType()->Params());
+	auto vargs = MakeCallArgumentVector(*vl, GetType()->Params());
 
-	Event* ev = new Event(new_event, {
-			zeek::make_intrusive<zeek::StringVal>(name),
+	auto ev = new Event(new_event, {
+			make_intrusive<StringVal>(name),
 			std::move(vargs),
 			});
-	mgr.Dispatch(ev);
+	event_mgr.Dispatch(ev);
 	}
+
+} // namespace zeek
