@@ -1,20 +1,21 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
+#include "zeek/OpaqueVal.h"
+
 #include <memory>
 
-#include "OpaqueVal.h"
-#include "CompHash.h"
-#include "NetVar.h"
-#include "Reporter.h"
-#include "Scope.h"
-#include "Desc.h"
-#include "Var.h"
-#include "probabilistic/BloomFilter.h"
-#include "probabilistic/CardinalityCounter.h"
-
 #include <broker/data.hh>
 #include <broker/error.hh>
 
+#include "zeek/CompHash.h"
+#include "zeek/NetVar.h"
+#include "zeek/Reporter.h"
+#include "zeek/Scope.h"
+#include "zeek/Desc.h"
+#include "zeek/Var.h"
+#include "zeek/probabilistic/BloomFilter.h"
+#include "zeek/probabilistic/CardinalityCounter.h"
+
 namespace zeek {
 
 // Helper to retrieve a broker value out of a broker::vector at a specified
@@ -39,10 +40,10 @@ OpaqueMgr* OpaqueMgr::mgr()
 	return &mgr;
 	}
 
-OpaqueVal::OpaqueVal(zeek::OpaqueType* t) : OpaqueVal({zeek::NewRef{}, t})
+OpaqueVal::OpaqueVal(OpaqueType* t) : OpaqueVal({NewRef{}, t})
 	{}
 
-OpaqueVal::OpaqueVal(zeek::OpaqueTypePtr t) : Val(std::move(t))
+OpaqueVal::OpaqueVal(OpaqueTypePtr t) : Val(std::move(t))
 	{}
 
 OpaqueVal::~OpaqueVal()
@@ -55,7 +56,7 @@ const std::string& OpaqueMgr::TypeID(const OpaqueVal* v) const
 
 	if ( x == _types.end() )
 		reporter->InternalError("OpaqueMgr::TypeID: opaque type %s not registered",
-					v->OpaqueName());
+		                              v->OpaqueName());
 
 	return x->first;
 	}
@@ -98,12 +99,12 @@ OpaqueValPtr OpaqueVal::Unserialize(const broker::data& data)
 	return val;
 	}
 
-broker::expected<broker::data> OpaqueVal::SerializeType(const zeek::TypePtr& t)
+broker::expected<broker::data> OpaqueVal::SerializeType(const TypePtr& t)
 	{
-	if ( t->InternalType() == zeek::TYPE_INTERNAL_ERROR )
+	if ( t->InternalType() == TYPE_INTERNAL_ERROR )
 		return broker::ec::invalid_data;
 
-	if ( t->InternalType() == zeek::TYPE_INTERNAL_OTHER )
+	if ( t->InternalType() == TYPE_INTERNAL_OTHER )
 		{
 		// Serialize by name.
 		assert(t->GetName().size());
@@ -114,7 +115,7 @@ broker::expected<broker::data> OpaqueVal::SerializeType(const zeek::TypePtr& t)
 	return {broker::vector{false, static_cast<uint64_t>(t->Tag())}};
 	}
 
-zeek::TypePtr OpaqueVal::UnserializeType(const broker::data& data)
+TypePtr OpaqueVal::UnserializeType(const broker::data& data)
 	{
 	auto v = caf::get_if<broker::vector>(&data);
 	if ( ! (v && v->size() == 2) )
@@ -130,7 +131,7 @@ zeek::TypePtr OpaqueVal::UnserializeType(const broker::data& data)
 		if ( ! name )
 			return nullptr;
 
-		const auto& id = zeek::detail::global_scope()->Find(*name);
+		const auto& id = detail::global_scope()->Find(*name);
 		if ( ! id )
 			return nullptr;
 
@@ -144,7 +145,7 @@ zeek::TypePtr OpaqueVal::UnserializeType(const broker::data& data)
 	if ( ! tag )
 		return nullptr;
 
-	return zeek::base_type(static_cast<zeek::TypeTag>(*tag));
+	return base_type(static_cast<TypeTag>(*tag));
 	}
 
 ValPtr OpaqueVal::DoClone(CloneState* state)
@@ -174,7 +175,7 @@ bool HashVal::Init()
 StringValPtr HashVal::Get()
 	{
 	if ( ! valid )
-		return zeek::val_mgr->EmptyString();
+		return val_mgr->EmptyString();
 
 	auto result = DoGet();
 	valid = false;
@@ -205,15 +206,15 @@ bool HashVal::DoFeed(const void*, size_t)
 StringValPtr HashVal::DoGet()
 	{
 	assert(! "missing implementation of DoGet()");
-	return zeek::val_mgr->EmptyString();
+	return val_mgr->EmptyString();
 	}
 
-HashVal::HashVal(zeek::OpaqueTypePtr t) : OpaqueVal(std::move(t))
+HashVal::HashVal(OpaqueTypePtr t) : OpaqueVal(std::move(t))
 	{
 	valid = false;
 	}
 
-HashVal::HashVal(zeek::OpaqueType* t) : HashVal({zeek::NewRef{}, t})
+HashVal::HashVal(OpaqueType* t) : HashVal({NewRef{}, t})
 	{}
 
 MD5Val::MD5Val() : HashVal(md5_type)
@@ -228,16 +229,16 @@ MD5Val::~MD5Val()
 
 void HashVal::digest_one(EVP_MD_CTX* h, const Val* v)
 	{
-	if ( v->GetType()->Tag() == zeek::TYPE_STRING )
+	if ( v->GetType()->Tag() == TYPE_STRING )
 		{
 		const String* str = v->AsString();
-		hash_update(h, str->Bytes(), str->Len());
+		detail::hash_update(h, str->Bytes(), str->Len());
 		}
 	else
 		{
 		ODesc d(DESC_BINARY);
 		v->Describe(&d);
-		hash_update(h, (const u_char *) d.Bytes(), d.Len());
+		detail::hash_update(h, (const u_char *) d.Bytes(), d.Len());
 		}
 	}
 
@@ -248,7 +249,7 @@ void HashVal::digest_one(EVP_MD_CTX* h, const ValPtr& v)
 
 ValPtr MD5Val::DoClone(CloneState* state)
 	{
-	auto out = zeek::make_intrusive<MD5Val>();
+	auto out = make_intrusive<MD5Val>();
 
 	if ( IsValid() )
 		{
@@ -264,7 +265,7 @@ ValPtr MD5Val::DoClone(CloneState* state)
 bool MD5Val::DoInit()
 	{
 	assert(! IsValid());
-	ctx = hash_init(Hash_MD5);
+	ctx = detail::hash_init(detail::Hash_MD5);
 	return true;
 	}
 
@@ -273,18 +274,18 @@ bool MD5Val::DoFeed(const void* data, size_t size)
 	if ( ! IsValid() )
 		return false;
 
-	hash_update(ctx, data, size);
+	detail::hash_update(ctx, data, size);
 	return true;
 	}
 
 StringValPtr MD5Val::DoGet()
 	{
 	if ( ! IsValid() )
-		return zeek::val_mgr->EmptyString();
+		return val_mgr->EmptyString();
 
 	u_char digest[MD5_DIGEST_LENGTH];
-	hash_final(ctx, digest);
-	return zeek::make_intrusive<StringVal>(md5_digest_print(digest));
+	detail::hash_final(ctx, digest);
+	return make_intrusive<StringVal>(detail::md5_digest_print(digest));
 	}
 
 IMPLEMENT_OPAQUE_VALUE(MD5Val)
@@ -368,7 +369,7 @@ SHA1Val::~SHA1Val()
 
 ValPtr SHA1Val::DoClone(CloneState* state)
 	{
-	auto out = zeek::make_intrusive<SHA1Val>();
+	auto out = make_intrusive<SHA1Val>();
 
 	if ( IsValid() )
 		{
@@ -384,7 +385,7 @@ ValPtr SHA1Val::DoClone(CloneState* state)
 bool SHA1Val::DoInit()
 	{
 	assert(! IsValid());
-	ctx = hash_init(Hash_SHA1);
+	ctx = detail::hash_init(detail::Hash_SHA1);
 	return true;
 	}
 
@@ -393,18 +394,18 @@ bool SHA1Val::DoFeed(const void* data, size_t size)
 	if ( ! IsValid() )
 		return false;
 
-	hash_update(ctx, data, size);
+	detail::hash_update(ctx, data, size);
 	return true;
 	}
 
 StringValPtr SHA1Val::DoGet()
 	{
 	if ( ! IsValid() )
-		return zeek::val_mgr->EmptyString();
+		return val_mgr->EmptyString();
 
 	u_char digest[SHA_DIGEST_LENGTH];
-	hash_final(ctx, digest);
-	return zeek::make_intrusive<StringVal>(sha1_digest_print(digest));
+	detail::hash_final(ctx, digest);
+	return make_intrusive<StringVal>(detail::sha1_digest_print(digest));
 	}
 
 IMPLEMENT_OPAQUE_VALUE(SHA1Val)
@@ -491,7 +492,7 @@ SHA256Val::~SHA256Val()
 
 ValPtr SHA256Val::DoClone(CloneState* state)
 	{
-	auto out = zeek::make_intrusive<SHA256Val>();
+	auto out = make_intrusive<SHA256Val>();
 
 	if ( IsValid() )
 		{
@@ -507,7 +508,7 @@ ValPtr SHA256Val::DoClone(CloneState* state)
 bool SHA256Val::DoInit()
 	{
 	assert( ! IsValid() );
-	ctx = hash_init(Hash_SHA256);
+	ctx = detail::hash_init(detail::Hash_SHA256);
 	return true;
 	}
 
@@ -516,18 +517,18 @@ bool SHA256Val::DoFeed(const void* data, size_t size)
 	if ( ! IsValid() )
 		return false;
 
-	hash_update(ctx, data, size);
+	detail::hash_update(ctx, data, size);
 	return true;
 	}
 
 StringValPtr SHA256Val::DoGet()
 	{
 	if ( ! IsValid() )
-		return zeek::val_mgr->EmptyString();
+		return val_mgr->EmptyString();
 
 	u_char digest[SHA256_DIGEST_LENGTH];
-	hash_final(ctx, digest);
-	return zeek::make_intrusive<StringVal>(sha256_digest_print(digest));
+	detail::hash_final(ctx, digest);
+	return make_intrusive<StringVal>(detail::sha256_digest_print(digest));
 	}
 
 IMPLEMENT_OPAQUE_VALUE(SHA256Val)
@@ -717,24 +718,24 @@ ValPtr BloomFilterVal::DoClone(CloneState* state)
 	{
 	if ( bloom_filter )
 		{
-		auto bf = zeek::make_intrusive<BloomFilterVal>(bloom_filter->Clone());
+		auto bf = make_intrusive<BloomFilterVal>(bloom_filter->Clone());
 		bf->Typify(type);
 		return state->NewClone(this, std::move(bf));
 		}
 
-	return state->NewClone(this, zeek::make_intrusive<BloomFilterVal>());
+	return state->NewClone(this, make_intrusive<BloomFilterVal>());
 	}
 
-bool BloomFilterVal::Typify(zeek::TypePtr arg_type)
+bool BloomFilterVal::Typify(TypePtr arg_type)
 	{
 	if ( type )
 		return false;
 
 	type = std::move(arg_type);
 
-	auto tl = zeek::make_intrusive<zeek::TypeList>(type);
+	auto tl = make_intrusive<TypeList>(type);
 	tl->Append(type);
-	hash = new CompositeHash(std::move(tl));
+	hash = new detail::CompositeHash(std::move(tl));
 
 	return true;
 	}
@@ -793,7 +794,7 @@ BloomFilterValPtr BloomFilterVal::Merge(const BloomFilterVal* x,
 		return nullptr;
 		}
 
-	auto merged = zeek::make_intrusive<BloomFilterVal>(copy);
+	auto merged = make_intrusive<BloomFilterVal>(copy);
 
 	if ( x->Type() && ! merged->Typify(x->Type()) )
 		{
@@ -865,7 +866,7 @@ CardinalityVal::CardinalityVal() : OpaqueVal(cardinality_type)
 	hash = nullptr;
 	}
 
-CardinalityVal::CardinalityVal(probabilistic::CardinalityCounter* arg_c)
+CardinalityVal::CardinalityVal(probabilistic::detail::CardinalityCounter* arg_c)
 	: OpaqueVal(cardinality_type)
 	{
 	c = arg_c;
@@ -881,19 +882,19 @@ CardinalityVal::~CardinalityVal()
 ValPtr CardinalityVal::DoClone(CloneState* state)
 	{
 	return state->NewClone(this,
-			       zeek::make_intrusive<CardinalityVal>(new probabilistic::CardinalityCounter(*c)));
+			       make_intrusive<CardinalityVal>(new probabilistic::detail::CardinalityCounter(*c)));
 	}
 
-bool CardinalityVal::Typify(zeek::TypePtr arg_type)
+bool CardinalityVal::Typify(TypePtr arg_type)
 	{
 	if ( type )
 		return false;
 
 	type = std::move(arg_type);
 
-	auto tl = zeek::make_intrusive<zeek::TypeList>(type);
+	auto tl = make_intrusive<TypeList>(type);
 	tl->Append(type);
-	hash = new CompositeHash(std::move(tl));
+	hash = new detail::CompositeHash(std::move(tl));
 
 	return true;
 	}
@@ -945,7 +946,7 @@ bool CardinalityVal::DoUnserialize(const broker::data& data)
 			return false;
 		}
 
-	auto cu = probabilistic::CardinalityCounter::Unserialize((*v)[1]);
+	auto cu = probabilistic::detail::CardinalityCounter::Unserialize((*v)[1]);
 	if ( ! cu )
 		return false;
 
@@ -961,12 +962,12 @@ ParaglobVal::ParaglobVal(std::unique_ptr<paraglob::Paraglob> p)
 
 VectorValPtr ParaglobVal::Get(StringVal* &pattern)
 	{
-	auto rval = zeek::make_intrusive<VectorVal>(zeek::id::string_vec);
+	auto rval = make_intrusive<VectorVal>(id::string_vec);
 	std::string string_pattern (reinterpret_cast<const char*>(pattern->Bytes()), pattern->Len());
 
 	std::vector<std::string> matches = this->internal_paraglob->get(string_pattern);
-	for (unsigned int i = 0; i < matches.size(); i++)
-		rval->Assign(i, zeek::make_intrusive<StringVal>(matches.at(i)));
+	for ( size_t i = 0; i < matches.size(); i++ )
+		rval->Assign(i, make_intrusive<StringVal>(matches.at(i)));
 
 	return rval;
 	}
@@ -1023,7 +1024,7 @@ bool ParaglobVal::DoUnserialize(const broker::data& data)
 ValPtr ParaglobVal::DoClone(CloneState* state)
 	{
 	try {
-		return zeek::make_intrusive<ParaglobVal>
+		return make_intrusive<ParaglobVal>
 			(std::make_unique<paraglob::Paraglob>(this->internal_paraglob->serialize()));
 		}
 	catch (const paraglob::underflow_error& e)
