@@ -1,19 +1,18 @@
-#include "Trigger.h"
-
-#include <algorithm>
+#include "zeek/Trigger.h"
 
 #include <assert.h>
+#include <algorithm>
 
-#include "Traverse.h"
-#include "Expr.h"
-#include "Frame.h"
-#include "ID.h"
-#include "Val.h"
-#include "Stmt.h"
-#include "Reporter.h"
-#include "Desc.h"
-#include "DebugLogger.h"
-#include "iosource/Manager.h"
+#include "zeek/Traverse.h"
+#include "zeek/Expr.h"
+#include "zeek/Frame.h"
+#include "zeek/ID.h"
+#include "zeek/Val.h"
+#include "zeek/Stmt.h"
+#include "zeek/Reporter.h"
+#include "zeek/Desc.h"
+#include "zeek/DebugLogger.h"
+#include "zeek/iosource/Manager.h"
 
 using namespace zeek::detail;
 using namespace zeek::detail::trigger;
@@ -31,13 +30,13 @@ public:
 	~TriggerTraversalCallback()
 		{ Unref(trigger); }
 
-	virtual TraversalCode PreExpr(const zeek::detail::Expr*) override;
+	virtual TraversalCode PreExpr(const Expr*) override;
 
 private:
 	Trigger* trigger;
 };
 
-TraversalCode zeek::detail::trigger::TriggerTraversalCallback::PreExpr(const zeek::detail::Expr* expr)
+TraversalCode trigger::TriggerTraversalCallback::PreExpr(const Expr* expr)
 	{
 	// We catch all expressions here which in some way reference global
 	// state.
@@ -45,7 +44,7 @@ TraversalCode zeek::detail::trigger::TriggerTraversalCallback::PreExpr(const zee
 	switch ( expr->Tag() ) {
 	case EXPR_NAME:
 		{
-		const auto* e = static_cast<const zeek::detail::NameExpr*>(expr);
+		const auto* e = static_cast<const NameExpr*>(expr);
 		if ( e->Id()->IsGlobal() )
 			trigger->Register(e->Id());
 
@@ -56,24 +55,6 @@ TraversalCode zeek::detail::trigger::TriggerTraversalCallback::PreExpr(const zee
 		break;
 		};
 
-	case EXPR_INDEX:
-		{
-		const auto* e = static_cast<const zeek::detail::IndexExpr*>(expr);
-		Obj::SuppressErrors no_errors;
-
-		try
-			{
-			auto v = e->Eval(trigger->frame);
-
-			if ( v )
-				trigger->Register(v.get());
-			}
-		catch ( InterpreterException& )
-			{ /* Already reported */ }
-
-		break;
-		}
-
 	default:
 		// All others are uninteresting.
 		break;
@@ -85,12 +66,12 @@ TraversalCode zeek::detail::trigger::TriggerTraversalCallback::PreExpr(const zee
 class TriggerTimer final : public Timer {
 public:
 	TriggerTimer(double arg_timeout, Trigger* arg_trigger)
-	: Timer(network_time + arg_timeout, TIMER_TRIGGER)
+	: Timer(run_state::network_time + arg_timeout, TIMER_TRIGGER)
 		{
 		Ref(arg_trigger);
 		trigger = arg_trigger;
 		timeout = arg_timeout;
-		time = network_time;
+		time = run_state::network_time;
 		}
 
 	~TriggerTimer()
@@ -117,10 +98,10 @@ protected:
 	double time;
 };
 
-Trigger::Trigger(zeek::detail::Expr* arg_cond, zeek::detail::Stmt* arg_body,
-			zeek::detail::Stmt* arg_timeout_stmts,
-			zeek::detail::Expr* arg_timeout, Frame* arg_frame,
-			bool arg_is_return, const Location* arg_location)
+Trigger::Trigger(Expr* arg_cond, Stmt* arg_body,
+                 Stmt* arg_timeout_stmts,
+                 Expr* arg_timeout, Frame* arg_frame,
+                 bool arg_is_return, const Location* arg_location)
 	{
 	cond = arg_cond;
 	body = arg_body;
@@ -217,12 +198,15 @@ Trigger::~Trigger()
 	// point.
 	}
 
-void Trigger::Init()
+void Trigger::Init(std::vector<ValPtr> index_expr_results)
 	{
 	assert(! disabled);
 	UnregisterAll();
 	TriggerTraversalCallback cb(this);
 	cond->Traverse(&cb);
+
+	for ( const auto& v : index_expr_results )
+		Register(v.get());
 	}
 
 bool Trigger::Eval()
@@ -262,9 +246,10 @@ bool Trigger::Eval()
 		return false;
 		}
 
-	f->SetTrigger({zeek::NewRef{}, this});
+	f->SetTrigger({NewRef{}, this});
 
 	ValPtr v;
+	IndexExprWhen::StartEval();
 
 	try
 		{
@@ -273,6 +258,9 @@ bool Trigger::Eval()
 	catch ( InterpreterException& )
 		{ /* Already reported */ }
 
+	IndexExprWhen::EndEval();
+	auto index_expr_results = IndexExprWhen::TakeAllResults();
+
 	f->ClearTrigger();
 
 	if ( f->HasDelayed() )
@@ -288,7 +276,7 @@ bool Trigger::Eval()
 		// Not true. Perhaps next time...
 		DBG_LOG(DBG_NOTIFIERS, "%s: trigger condition is false", Name());
 		Unref(f);
-		Init();
+		Init(std::move(index_expr_results));
 		return false;
 		}
 
@@ -296,7 +284,7 @@ bool Trigger::Eval()
 			Name());
 
 	v = nullptr;
-	stmt_flow_type flow;
+	StmtFlowType flow;
 
 	try
 		{
@@ -313,7 +301,7 @@ bool Trigger::Eval()
 		assert(trigger->attached == this);
 
 #ifdef DEBUG
-		const char* pname = copy_string(trigger->Name());
+		const char* pname = util::copy_string(trigger->Name());
 		DBG_LOG(DBG_NOTIFIERS, "%s: trigger has parent %s, caching result", Name(), pname);
 		delete [] pname;
 #endif
@@ -347,8 +335,8 @@ void Trigger::Timeout()
 	DBG_LOG(DBG_NOTIFIERS, "%s: timeout", Name());
 	if ( timeout_stmts )
 		{
-		stmt_flow_type flow;
-		FramePtr f{zeek::AdoptRef{}, frame->Clone()};
+		StmtFlowType flow;
+		FramePtr f{AdoptRef{}, frame->Clone()};
 		ValPtr v;
 
 		try
@@ -366,7 +354,7 @@ void Trigger::Timeout()
 			assert(trigger->attached == this);
 
 #ifdef DEBUG
-			const char* pname = copy_string(trigger->Name());
+			const char* pname = util::copy_string(trigger->Name());
 			DBG_LOG(DBG_NOTIFIERS, "%s: trigger has parent %s, caching timeout result", Name(), pname);
 			delete [] pname;
 #endif
@@ -385,10 +373,10 @@ void Trigger::Timeout()
 	Unref(this);
 	}
 
-void Trigger::Register(zeek::detail::ID* id)
+void Trigger::Register(ID* id)
 	{
 	assert(! disabled);
-	notifier::registry.Register(id, this);
+	notifier::detail::registry.Register(id, this);
 
 	Ref(id);
 	objs.push_back({id, id});
@@ -400,7 +388,7 @@ void Trigger::Register(Val* val)
 		return;
 
 	assert(! disabled);
-	notifier::registry.Register(val->Modifiable(), this);
+	notifier::detail::registry.Register(val->Modifiable(), this);
 
 	Ref(val);
 	objs.emplace_back(val, val->Modifiable());
@@ -412,7 +400,7 @@ void Trigger::UnregisterAll()
 
 	for ( const auto& o : objs )
 		{
-		notifier::registry.Unregister(o.second, this);
+		notifier::detail::registry.Unregister(o.second, this);
 		Unref(o.first);
 		}
 
@@ -426,7 +414,7 @@ void Trigger::Attach(Trigger *trigger)
 	assert(! trigger->delayed);
 
 #ifdef DEBUG
-	const char* pname = copy_string(trigger->Name());
+	const char* pname = util::copy_string(trigger->Name());
 	DBG_LOG(DBG_NOTIFIERS, "%s: attaching to %s", Name(), pname);
 	delete [] pname;
 #endif
@@ -436,7 +424,7 @@ void Trigger::Attach(Trigger *trigger)
 	Hold();
 	}
 
-bool Trigger::Cache(const zeek::detail::CallExpr* expr, Val* v)
+bool Trigger::Cache(const CallExpr* expr, Val* v)
 	{
 	if ( disabled || ! v )
 		return false;
@@ -459,7 +447,7 @@ bool Trigger::Cache(const zeek::detail::CallExpr* expr, Val* v)
 	}
 
 
-Val* Trigger::Lookup(const zeek::detail::CallExpr* expr)
+Val* Trigger::Lookup(const CallExpr* expr)
 	{
 	assert(! disabled);
 
@@ -478,7 +466,7 @@ void Trigger::Describe(ODesc* d) const
 	d->Add("<trigger>");
 	}
 
-void Trigger::Modified(notifier::Modifiable* m)
+void Trigger::Modified(notifier::detail::Modifiable* m)
 	{
 	trigger_mgr->Queue(this);
 	}
@@ -486,13 +474,13 @@ void Trigger::Modified(notifier::Modifiable* m)
 const char* Trigger::Name() const
 	{
 	assert(location);
-	return fmt("%s:%d-%d", location->filename,
-			location->first_line, location->last_line);
+	return util::fmt("%s:%d-%d", location->filename,
+	                       location->first_line, location->last_line);
 	}
 
 
 
-Manager::Manager() : IOSource()
+Manager::Manager() : iosource::IOSource()
 	{
 	pending = new TriggerList();
 	iosource_mgr->Register(this, true);
@@ -505,7 +493,7 @@ Manager::~Manager()
 
 double Manager::GetNextTimeout()
 	{
-	return pending->empty() ? -1 : network_time + 0.100;
+	return pending->empty() ? -1 : run_state::network_time + 0.100;
 	}
 
 void Manager::Process()
