@@ -1,15 +1,15 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "Component.h"
-#include "Manager.h"
+#include "zeek/analyzer/Component.h"
 
-#include "../Desc.h"
-#include "../util.h"
+#include "zeek/analyzer/Manager.h"
+#include "zeek/Desc.h"
+#include "zeek/util.h"
 
-using namespace analyzer;
+namespace zeek::analyzer {
 
 Component::Component(const std::string& name, factory_callback arg_factory, Tag::subtype_t arg_subtype, bool arg_enabled, bool arg_partial)
-	: zeek::plugin::Component(zeek::plugin::component::ANALYZER, name),
+	: plugin::Component(plugin::component::ANALYZER, name),
 	  plugin::TaggedComponent<analyzer::Tag>(arg_subtype)
 	{
 	factory = arg_factory;
@@ -38,3 +38,5 @@ void Component::DoDescribe(ODesc* d) const
 
 	d->Add(enabled ? "enabled" : "disabled");
 	}
+
+} // namespace zeek::analyzer
