@@ -1,26 +1,27 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "Manager.h"
+#include "zeek/analyzer/Manager.h"
 
-#include "Hash.h"
-#include "Val.h"
-#include "IntrusivePtr.h"
+#include "zeek/Hash.h"
+#include "zeek/Val.h"
+#include "zeek/IntrusivePtr.h"
+#include "zeek/RunState.h"
 
-#include "protocol/conn-size/ConnSize.h"
-#include "protocol/icmp/ICMP.h"
-#include "protocol/pia/PIA.h"
-#include "protocol/stepping-stone/SteppingStone.h"
-#include "protocol/tcp/TCP.h"
-#include "protocol/udp/UDP.h"
+#include "zeek/analyzer/protocol/conn-size/ConnSize.h"
+#include "zeek/analyzer/protocol/icmp/ICMP.h"
+#include "zeek/analyzer/protocol/pia/PIA.h"
+#include "zeek/analyzer/protocol/stepping-stone/SteppingStone.h"
+#include "zeek/analyzer/protocol/tcp/TCP.h"
+#include "zeek/analyzer/protocol/udp/UDP.h"
 
-#include "plugin/Manager.h"
+#include "zeek/plugin/Manager.h"
 
-#include "protocol/tcp/events.bif.h"
+#include "analyzer/protocol/tcp/events.bif.h"
 
-using namespace analyzer;
+namespace zeek::analyzer {
 
 Manager::ConnIndex::ConnIndex(const IPAddr& _orig, const IPAddr& _resp,
-				     uint16_t _resp_p, uint16_t _proto)
+                              uint16_t _resp_p, uint16_t _proto)
 	{
 	if ( _orig == IPAddr::v4_unspecified )
 		// don't use the IPv4 mapping, use the literal unspecified address
@@ -90,7 +91,7 @@ void Manager::InitPreScript()
 
 void Manager::InitPostScript()
 	{
-	const auto& id = zeek::detail::global_scope()->Find("Tunnel::vxlan_ports");
+	const auto& id = detail::global_scope()->Find("Tunnel::vxlan_ports");
 
 	if ( ! (id && id->GetVal()) )
 		reporter->FatalError("Tunnel::vxlan_ports not defined");
@@ -109,7 +110,7 @@ void Manager::DumpDebug()
 	std::list<Component*> all_analyzers = GetComponents();
 	for ( std::list<Component*>::const_iterator i = all_analyzers.begin(); i != all_analyzers.end(); ++i )
 		DBG_LOG(DBG_ANALYZER, "    %s (%s)", (*i)->Name().c_str(),
-			IsEnabled((*i)->Tag()) ? "enabled" : "disabled");
+		        IsEnabled((*i)->Tag()) ? "enabled" : "disabled");
 
 	DBG_LOG(DBG_ANALYZER, " ");
 	DBG_LOG(DBG_ANALYZER, "Analyzers by port:");
@@ -154,7 +155,7 @@ bool Manager::EnableAnalyzer(const Tag& tag)
 	return true;
 	}
 
-bool Manager::EnableAnalyzer(zeek::EnumVal* val)
+bool Manager::EnableAnalyzer(EnumVal* val)
 	{
 	Component* p = Lookup(val);
 
@@ -180,7 +181,7 @@ bool Manager::DisableAnalyzer(const Tag& tag)
 	return true;
 	}
 
-bool Manager::DisableAnalyzer(zeek::EnumVal* val)
+bool Manager::DisableAnalyzer(EnumVal* val)
 	{
 	Component* p = Lookup(val);
 
@@ -220,7 +221,7 @@ bool Manager::IsEnabled(const Tag& tag)
 	return p->Enabled();
 	}
 
-bool Manager::IsEnabled(zeek::EnumVal* val)
+bool Manager::IsEnabled(EnumVal* val)
 	{
 	Component* p = Lookup(val);
 
@@ -231,7 +232,7 @@ bool Manager::IsEnabled(zeek::EnumVal* val)
 	}
 
 
-bool Manager::RegisterAnalyzerForPort(zeek::EnumVal* val, zeek::PortVal* port)
+bool Manager::RegisterAnalyzerForPort(EnumVal* val, PortVal* port)
 	{
 	Component* p = Lookup(val);
 
@@ -241,7 +242,7 @@ bool Manager::RegisterAnalyzerForPort(zeek::EnumVal* val, zeek::PortVal* port)
 	return RegisterAnalyzerForPort(p->Tag(), port->PortType(), port->Port());
 	}
 
-bool Manager::UnregisterAnalyzerForPort(zeek::EnumVal* val, zeek::PortVal* port)
+bool Manager::UnregisterAnalyzerForPort(EnumVal* val, PortVal* port)
 	{
 	Component* p = Lookup(val);
 
@@ -353,38 +354,36 @@ Manager::tag_set* Manager::LookupPort(TransportProto proto, uint32_t port, bool
 	return l;
 	}
 
-Manager::tag_set* Manager::LookupPort(zeek::PortVal* val, bool add_if_not_found)
+Manager::tag_set* Manager::LookupPort(PortVal* val, bool add_if_not_found)
 	{
 	return LookupPort(val->PortType(), val->Port(), add_if_not_found);
 	}
 
 bool Manager::BuildInitialAnalyzerTree(Connection* conn)
 	{
-	tcp::TCP_Analyzer* tcp = nullptr;
-	udp::UDP_Analyzer* udp = nullptr;
-	icmp::ICMP_Analyzer* icmp = nullptr;
+	analyzer::tcp::TCP_Analyzer* tcp = nullptr;
 	TransportLayerAnalyzer* root = nullptr;
-	pia::PIA* pia = nullptr;
+	analyzer::pia::PIA* pia = nullptr;
 	bool check_port = false;
 
 	switch ( conn->ConnTransport() ) {
 
 	case TRANSPORT_TCP:
-		root = tcp = new tcp::TCP_Analyzer(conn);
-		pia = new pia::PIA_TCP(conn);
+		root = tcp = new analyzer::tcp::TCP_Analyzer(conn);
+		pia = new analyzer::pia::PIA_TCP(conn);
 		check_port = true;
 		DBG_ANALYZER(conn, "activated TCP analyzer");
 		break;
 
 	case TRANSPORT_UDP:
-		root = udp = new udp::UDP_Analyzer(conn);
-		pia = new pia::PIA_UDP(conn);
+		root = new analyzer::udp::UDP_Analyzer(conn);
+		pia = new analyzer::pia::PIA_UDP(conn);
 		check_port = true;
 		DBG_ANALYZER(conn, "activated UDP analyzer");
 		break;
 
 	case TRANSPORT_ICMP: {
-		root = icmp = new icmp::ICMP_Analyzer(conn);
+		root = new analyzer::icmp::ICMP_Analyzer(conn);
 		DBG_ANALYZER(conn, "activated ICMP analyzer");
 		break;
 		}
@@ -401,7 +400,7 @@ bool Manager::BuildInitialAnalyzerTree(Connection* conn)
 	// the scheduled ones.
 	if ( ! scheduled )
 		{ // Let's see if it's a port we know.
-		if ( check_port && ! dpd_ignore_ports )
+		if ( check_port && ! zeek::detail::dpd_ignore_ports )
 			{
 			int resp_port = ntohs(conn->RespPort());
 			tag_set* ports = LookupPort(conn->ConnTransport(), resp_port, false);
@@ -417,7 +416,7 @@ bool Manager::BuildInitialAnalyzerTree(Connection* conn)
 
 					root->AddChildAnalyzer(analyzer, false);
 					DBG_ANALYZER_ARGS(conn, "activated %s analyzer due to port %d",
-							  analyzer_mgr->GetComponentName(*j).c_str(), resp_port);
+					                  analyzer_mgr->GetComponentName(*j).c_str(), resp_port);
 					}
 				}
 			}
@@ -432,15 +431,15 @@ bool Manager::BuildInitialAnalyzerTree(Connection* conn)
 		// be turned on later by the TCP PIA.
 
 		bool reass = root->GetChildren().size() ||
-				dpd_reassemble_first_packets ||
-				tcp_content_deliver_all_orig ||
-				tcp_content_deliver_all_resp;
+				zeek::detail::dpd_reassemble_first_packets ||
+				zeek::detail::tcp_content_deliver_all_orig ||
+				zeek::detail::tcp_content_deliver_all_resp;
 
 		if ( tcp_contents && ! reass )
 			{
-			static auto tcp_content_delivery_ports_orig = zeek::id::find_val<zeek::TableVal>("tcp_content_delivery_ports_orig");
-			static auto tcp_content_delivery_ports_resp = zeek::id::find_val<zeek::TableVal>("tcp_content_delivery_ports_resp");
-			const auto& dport = zeek::val_mgr->Port(ntohs(conn->RespPort()), TRANSPORT_TCP);
+			static auto tcp_content_delivery_ports_orig = id::find_val<TableVal>("tcp_content_delivery_ports_orig");
+			static auto tcp_content_delivery_ports_resp = id::find_val<TableVal>("tcp_content_delivery_ports_resp");
+			const auto& dport = val_mgr->Port(ntohs(conn->RespPort()), TRANSPORT_TCP);
 
 			if ( ! reass )
 				reass = (bool)tcp_content_delivery_ports_orig->FindOrDefault(dport);
@@ -462,29 +461,29 @@ bool Manager::BuildInitialAnalyzerTree(Connection* conn)
 			uint16_t resp_port = ntohs(conn->RespPort());
 			if ( resp_port == 22 || resp_port == 23 || resp_port == 513 )
 				{
-				static auto stp_skip_src = zeek::id::find_val<zeek::TableVal>("stp_skip_src");
-				auto src = zeek::make_intrusive<zeek::AddrVal>(conn->OrigAddr());
+				static auto stp_skip_src = id::find_val<TableVal>("stp_skip_src");
+				auto src = make_intrusive<AddrVal>(conn->OrigAddr());
 
 				if ( ! stp_skip_src->FindOrDefault(src) )
-					tcp->AddChildAnalyzer(new stepping_stone::SteppingStone_Analyzer(conn), false);
+					tcp->AddChildAnalyzer(new analyzer::stepping_stone::SteppingStone_Analyzer(conn), false);
 				}
 			}
 
 		if ( IsEnabled(analyzer_tcpstats) )
 			// Add TCPStats analyzer. This needs to see packets so
 			// we cannot add it as a normal child.
-			tcp->AddChildPacketAnalyzer(new tcp::TCPStats_Analyzer(conn));
+			tcp->AddChildPacketAnalyzer(new analyzer::tcp::TCPStats_Analyzer(conn));
 
 		if ( IsEnabled(analyzer_connsize) )
 			// Add ConnSize analyzer. Needs to see packets, not stream.
-			tcp->AddChildPacketAnalyzer(new conn_size::ConnSize_Analyzer(conn));
+			tcp->AddChildPacketAnalyzer(new analyzer::conn_size::ConnSize_Analyzer(conn));
 		}
 
 	else
 		{
 		if ( IsEnabled(analyzer_connsize) )
 			// Add ConnSize analyzer. Needs to see packets, not stream.
-			root->AddChildAnalyzer(new conn_size::ConnSize_Analyzer(conn));
+			root->AddChildAnalyzer(new analyzer::conn_size::ConnSize_Analyzer(conn));
 		}
 
 	if ( pia )
@@ -501,14 +500,14 @@ bool Manager::BuildInitialAnalyzerTree(Connection* conn)
 
 void Manager::ExpireScheduledAnalyzers()
 	{
-	if ( ! network_time )
+	if ( ! run_state::network_time )
 		return;
 
 	while ( conns_by_timeout.size() )
 		{
 		ScheduledAnalyzer* a = conns_by_timeout.top();
 
-		if ( a->timeout > network_time )
+		if ( a->timeout > run_state::network_time )
 			return;
 
 		conns_by_timeout.pop();
@@ -525,8 +524,8 @@ void Manager::ExpireScheduledAnalyzers()
 			conns.erase(i);
 
 			DBG_LOG(DBG_ANALYZER, "Expiring expected analyzer %s for connection %s",
-				analyzer_mgr->GetComponentName(a->analyzer).c_str(),
-				fmt_conn_id(a->conn.orig, 0, a->conn.resp, a->conn.resp_p));
+			        analyzer_mgr->GetComponentName(a->analyzer).c_str(),
+			        fmt_conn_id(a->conn.orig, 0, a->conn.resp, a->conn.resp_p));
 
 			delete a;
 			found = true;
@@ -542,7 +541,7 @@ void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp,
 			TransportProto proto, const Tag& analyzer,
 			double timeout)
 	{
-	if ( ! network_time )
+	if ( ! run_state::network_time )
 		{
 		reporter->Warning("cannot schedule analyzers before processing begins; ignored");
 		return;
@@ -556,7 +555,7 @@ void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp,
 	ScheduledAnalyzer* a = new ScheduledAnalyzer;
 	a->conn = ConnIndex(orig, resp, resp_p, proto);
 	a->analyzer = analyzer;
-	a->timeout = network_time + timeout;
+	a->timeout = run_state::network_time + timeout;
 
 	conns.insert(std::make_pair(a->conn, a));
 	conns_by_timeout.push(a);
@@ -573,10 +572,10 @@ void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp,
 		ScheduleAnalyzer(orig, resp, resp_p, proto, tag, timeout);
 	}
 
-void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp, zeek::PortVal* resp_p,
-                               zeek::Val* analyzer, double timeout)
+void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp, PortVal* resp_p,
+                               Val* analyzer, double timeout)
 	{
-	zeek::EnumValPtr ev{zeek::NewRef{}, analyzer->AsEnumVal()};
+	EnumValPtr ev{NewRef{}, analyzer->AsEnumVal()};
 	return ScheduleAnalyzer(orig, resp, resp_p->Port(), resp_p->PortType(),
 	                        Tag(std::move(ev)), timeout);
 	}
@@ -599,7 +598,7 @@ Manager::tag_set Manager::GetScheduled(const Connection* conn)
 
 	for ( conns_map::iterator i = all.first; i != all.second; i++ )
 		{
-		if ( i->second->timeout > network_time )
+		if ( i->second->timeout > run_state::network_time )
 			result.insert(i->second->analyzer);
 		}
 
@@ -637,3 +636,5 @@ bool Manager::ApplyScheduledAnalyzers(Connection* conn, bool init, TransportLaye
 
 	return expected.size();
 	}
+
+} // namespace zeek::analyzer
