@@ -2,15 +2,16 @@
 //
 // See ConnSize.h for more extensive comments.
 
+#include "zeek/analyzer/protocol/conn-size/ConnSize.h"
 
-#include "ConnSize.h"
-#include "analyzer/protocol/tcp/TCP.h"
-#include "IP.h"
-#include "Reporter.h"
+#include "zeek/analyzer/protocol/tcp/TCP.h"
+#include "zeek/IP.h"
+#include "zeek/Reporter.h"
+#include "zeek/RunState.h"
 
-#include "events.bif.h"
+#include "analyzer/protocol/conn-size/events.bif.h"
 
-using namespace analyzer::conn_size;
+namespace zeek::analyzer::conn_size {
 
 ConnSize_Analyzer::ConnSize_Analyzer(Connection* c)
     : Analyzer("CONNSIZE", c),
@@ -52,8 +53,8 @@ void ConnSize_Analyzer::ThresholdEvent(EventHandlerPtr f, uint64_t threshold, bo
 
 	EnqueueConnEvent(f,
 		ConnVal(),
-		zeek::val_mgr->Count(threshold),
-		zeek::val_mgr->Bool(is_orig)
+		val_mgr->Count(threshold),
+		val_mgr->Bool(is_orig)
 	);
 	}
 
@@ -90,12 +91,12 @@ void ConnSize_Analyzer::CheckThresholds(bool is_orig)
 
 	if ( duration_thresh != 0 )
 		{
-		if ( ( network_time - start_time ) > duration_thresh && conn_duration_threshold_crossed )
+		if ( ( run_state::network_time - start_time ) > duration_thresh && conn_duration_threshold_crossed )
 			{
 			EnqueueConnEvent(conn_duration_threshold_crossed,
 					ConnVal(),
-					zeek::make_intrusive<zeek::IntervalVal>(duration_thresh),
-					zeek::val_mgr->Bool(is_orig)
+					make_intrusive<IntervalVal>(duration_thresh),
+					val_mgr->Bool(is_orig)
 			);
 			duration_thresh = 0;
 			}
@@ -167,15 +168,15 @@ void ConnSize_Analyzer::SetDurationThreshold(double duration)
 	CheckThresholds(true);
 	}
 
-void ConnSize_Analyzer::UpdateConnVal(zeek::RecordVal *conn_val)
+void ConnSize_Analyzer::UpdateConnVal(RecordVal *conn_val)
 	{
 	// RecordType *connection_type is decleared in NetVar.h
-	zeek::RecordVal* orig_endp = conn_val->GetField("orig")->AsRecordVal();
-	zeek::RecordVal* resp_endp = conn_val->GetField("resp")->AsRecordVal();
+	RecordVal* orig_endp = conn_val->GetField("orig")->AsRecordVal();
+	RecordVal* resp_endp = conn_val->GetField("resp")->AsRecordVal();
 
 	// endpoint is the RecordType from NetVar.h
-	int pktidx = zeek::id::endpoint->FieldOffset("num_pkts");
-	int bytesidx = zeek::id::endpoint->FieldOffset("num_bytes_ip");
+	int pktidx = id::endpoint->FieldOffset("num_pkts");
+	int bytesidx = id::endpoint->FieldOffset("num_bytes_ip");
 
 	if ( pktidx < 0 )
 		reporter->InternalError("'endpoint' record missing 'num_pkts' field");
@@ -183,10 +184,10 @@ void ConnSize_Analyzer::UpdateConnVal(zeek::RecordVal *conn_val)
 	if ( bytesidx < 0 )
 		reporter->InternalError("'endpoint' record missing 'num_bytes_ip' field");
 
-	orig_endp->Assign(pktidx, zeek::val_mgr->Count(orig_pkts));
-	orig_endp->Assign(bytesidx, zeek::val_mgr->Count(orig_bytes));
-	resp_endp->Assign(pktidx, zeek::val_mgr->Count(resp_pkts));
-	resp_endp->Assign(bytesidx, zeek::val_mgr->Count(resp_bytes));
+	orig_endp->Assign(pktidx, val_mgr->Count(orig_pkts));
+	orig_endp->Assign(bytesidx, val_mgr->Count(orig_bytes));
+	resp_endp->Assign(pktidx, val_mgr->Count(resp_pkts));
+	resp_endp->Assign(bytesidx, val_mgr->Count(resp_bytes));
 
 	Analyzer::UpdateConnVal(conn_val);
 	}
@@ -205,3 +206,5 @@ void ConnSize_Analyzer::FlipRoles()
 	orig_pkts = resp_pkts;
 	resp_pkts = tmp;
 	}
+
+} // namespace zeek::analyzer::conn_size
