@@ -3,14 +3,15 @@
 // TODO: This is preliminary code that's not yet functional and not
 // activated. We don't yet support SIP-over-TCP.
 
-#include "SIP_TCP.h"
-#include "analyzer/protocol/tcp/TCP_Reassembler.h"
-#include "events.bif.h"
+#include "zeek/analyzer/protocol/sip/SIP_TCP.h"
+#include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
 
-using namespace analyzer::sip_tcp;
+#include "analyzer/protocol/sip/events.bif.h"
+
+namespace zeek::analyzer::sip_tcp {
 
 SIP_Analyzer::SIP_Analyzer(Connection* conn)
-	: tcp::TCP_ApplicationAnalyzer("SIP_TCP", conn)
+	: analyzer::tcp::TCP_ApplicationAnalyzer("SIP_TCP", conn)
 	{
 	interp = new binpac::SIP_TCP::SIP_Conn(this);
 	had_gap = false;
@@ -23,7 +24,7 @@ SIP_Analyzer::~SIP_Analyzer()
 
 void SIP_Analyzer::Done()
 	{
-	tcp::TCP_ApplicationAnalyzer::Done();
+	analyzer::tcp::TCP_ApplicationAnalyzer::Done();
 
 	interp->FlowEOF(true);
 	interp->FlowEOF(false);
@@ -31,13 +32,13 @@ void SIP_Analyzer::Done()
 
 void SIP_Analyzer::EndpointEOF(bool is_orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::EndpointEOF(is_orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::EndpointEOF(is_orig);
 	interp->FlowEOF(is_orig);
 	}
 
 void SIP_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
 
 	assert(TCP());
 	if ( TCP()->IsPartial() )
@@ -55,13 +56,15 @@ void SIP_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 		}
 	catch ( const binpac::Exception& e )
 		{
-		ProtocolViolation(fmt("Binpac exception: %s", e.c_msg()));
+		ProtocolViolation(util::fmt("Binpac exception: %s", e.c_msg()));
 		}
 	}
 
 void SIP_Analyzer::Undelivered(uint64_t seq, int len, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
 	had_gap = true;
 	interp->NewGap(orig, len);
 	}
+
+} // namespace zeek::analyzer::sip_tcp
