@@ -1,18 +1,17 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "SSH.h"
+#include "zeek/analyzer/protocol/ssh/SSH.h"
 
-#include "analyzer/protocol/tcp/TCP_Reassembler.h"
+#include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
+#include "zeek/Reporter.h"
 
-#include "Reporter.h"
+#include "analyzer/protocol/ssh/types.bif.h"
+#include "analyzer/protocol/ssh/events.bif.h"
 
-#include "types.bif.h"
-#include "events.bif.h"
-
-using namespace analyzer::SSH;
+namespace zeek::analyzer::ssh {
 
 SSH_Analyzer::SSH_Analyzer(Connection* c)
-	: tcp::TCP_ApplicationAnalyzer("SSH", c)
+	: analyzer::tcp::TCP_ApplicationAnalyzer("SSH", c)
 	{
 	interp = new binpac::SSH::SSH_Conn(this);
 	had_gap = false;
@@ -30,7 +29,7 @@ SSH_Analyzer::~SSH_Analyzer()
 
 void SSH_Analyzer::Done()
 	{
-	tcp::TCP_ApplicationAnalyzer::Done();
+	analyzer::tcp::TCP_ApplicationAnalyzer::Done();
 
 	interp->FlowEOF(true);
 	interp->FlowEOF(false);
@@ -38,13 +37,13 @@ void SSH_Analyzer::Done()
 
 void SSH_Analyzer::EndpointEOF(bool is_orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::EndpointEOF(is_orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::EndpointEOF(is_orig);
 	interp->FlowEOF(is_orig);
 	}
 
 void SSH_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
 
 	assert(TCP());
 	if ( TCP()->IsPartial() )
@@ -69,7 +68,7 @@ void SSH_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 		}
 	catch ( const binpac::Exception& e )
 		{
-		ProtocolViolation(fmt("Binpac exception: %s", e.c_msg()));
+		ProtocolViolation(util::fmt("Binpac exception: %s", e.c_msg()));
 		}
 
 	auto encrypted_len = interp->get_encrypted_bytes_in_current_segment();
@@ -83,7 +82,7 @@ void SSH_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 
 void SSH_Analyzer::Undelivered(uint64_t seq, int len, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
 	had_gap = true;
 	interp->NewGap(orig, len);
 	}
@@ -91,8 +90,8 @@ void SSH_Analyzer::Undelivered(uint64_t seq, int len, bool orig)
 void SSH_Analyzer::ProcessEncryptedSegment(int len, bool orig)
 	{
 	if ( ssh_encrypted_packet )
-		zeek::BifEvent::enqueue_ssh_encrypted_packet(interp->bro_analyzer(),
-		                                       interp->bro_analyzer()->Conn(),
+		BifEvent::enqueue_ssh_encrypted_packet(interp->zeek_analyzer(),
+		                                       interp->zeek_analyzer()->Conn(),
 		                                       orig, len);
 
 	if ( ! auth_decision_made )
@@ -132,9 +131,9 @@ void SSH_Analyzer::ProcessEncrypted(int len, bool orig)
 			{
 			auth_decision_made = true;
 			if ( ssh_auth_attempted )
-				zeek::BifEvent::enqueue_ssh_auth_attempted(interp->bro_analyzer(), interp->bro_analyzer()->Conn(), true);
+				BifEvent::enqueue_ssh_auth_attempted(interp->zeek_analyzer(), interp->zeek_analyzer()->Conn(), true);
 			if ( ssh_auth_successful )
-				zeek::BifEvent::enqueue_ssh_auth_successful(interp->bro_analyzer(), interp->bro_analyzer()->Conn(), true);
+				BifEvent::enqueue_ssh_auth_successful(interp->zeek_analyzer(), interp->zeek_analyzer()->Conn(), true);
 			return;
 			}
 
@@ -159,7 +158,7 @@ void SSH_Analyzer::ProcessEncrypted(int len, bool orig)
 		if ( len == userauth_failure_size )
 			{
 			if ( ssh_auth_attempted )
-				zeek::BifEvent::enqueue_ssh_auth_attempted(interp->bro_analyzer(), interp->bro_analyzer()->Conn(), false);
+				BifEvent::enqueue_ssh_auth_attempted(interp->zeek_analyzer(), interp->zeek_analyzer()->Conn(), false);
 			return;
 			}
 
@@ -168,10 +167,12 @@ void SSH_Analyzer::ProcessEncrypted(int len, bool orig)
 			{
 			auth_decision_made = true;
 			if ( ssh_auth_attempted )
-				zeek::BifEvent::enqueue_ssh_auth_attempted(interp->bro_analyzer(), interp->bro_analyzer()->Conn(), true);
+				BifEvent::enqueue_ssh_auth_attempted(interp->zeek_analyzer(), interp->zeek_analyzer()->Conn(), true);
 			if ( ssh_auth_successful )
-				zeek::BifEvent::enqueue_ssh_auth_successful(interp->bro_analyzer(), interp->bro_analyzer()->Conn(), false);
+				BifEvent::enqueue_ssh_auth_successful(interp->zeek_analyzer(), interp->zeek_analyzer()->Conn(), false);
 			return;
 			}
 		}
 	}
+
+} // namespace zeek::analyzer::ssh
