@@ -4,9 +4,11 @@
  * Wrapper and helper functions for MD5/SHA digest algorithms.
  */
 
-#include "digest.h"
+#include "zeek/digest.h"
 
-#include "Reporter.h"
+#include "zeek/Reporter.h"
+
+namespace zeek::detail {
 
 EVP_MD_CTX* hash_init(HashAlgorithm alg)
 	{
@@ -79,3 +81,5 @@ unsigned char* calculate_digest(HashAlgorithm alg, const unsigned char* data, ui
 	hash_final(c, out);
 	return out;
 	}
+
+} // namespace zeek::detail
