@@ -2,22 +2,22 @@
 
 #pragma once
 
-#include "Tag.h"
-#include "plugin/Component.h"
-#include "plugin/TaggedComponent.h"
+#include "zeek/zeek-config.h"
 
-#include "../zeek-config.h"
+#include "zeek/file_analysis/Tag.h"
+#include "zeek/plugin/Component.h"
+#include "zeek/plugin/TaggedComponent.h"
 
 ZEEK_FORWARD_DECLARE_NAMESPACED(RecordVal, zeek);
 namespace zeek {
 using RecordValPtr = zeek::IntrusivePtr<RecordVal>;
 }
 
-namespace file_analysis {
+ZEEK_FORWARD_DECLARE_NAMESPACED(File, zeek, file_analysis);
+ZEEK_FORWARD_DECLARE_NAMESPACED(Analyzer, zeek, file_analysis);
+ZEEK_FORWARD_DECLARE_NAMESPACED(Manager, zeek, file_analysis);
 
-class File;
-class Analyzer;
-class Manager;
+namespace zeek::file_analysis {
 
 /**
  * Component description for plugins providing file analyzers.
@@ -25,11 +25,11 @@ class Manager;
  * A plugin can provide a specific file analyzer by registering this
  * analyzer component, describing the analyzer.
  */
-class Component : public zeek::plugin::Component,
+class Component : public plugin::Component,
                   public plugin::TaggedComponent<file_analysis::Tag> {
 public:
-	typedef Analyzer* (*factory_callback)(zeek::RecordVal* args, File* file);
-	using factory_function = Analyzer* (*)(zeek::RecordValPtr args, File* file);
+	typedef Analyzer* (*factory_callback)(RecordVal* args, File* file);
+	using factory_function = Analyzer* (*)(RecordValPtr args, File* file);
 
 	/**
 	 * Constructor.
@@ -83,10 +83,16 @@ protected:
 	void DoDescribe(ODesc* d) const override;
 
 private:
-	friend class file_analysis::Manager;
+	friend class Manager;
 
 	factory_callback factory;	// The analyzer's factory callback (deprecated).
 	factory_function factory_func;	// The analyzer's factory callback.
 };
 
-}
+} // namespace zeek::file_analysis
+
+namespace file_analysis {
+
+using Component [[deprecated("Remove in v4.1. Use zeek::file_analysis::Component.")]] = zeek::file_analysis::Component;
+
+} // namespace file_analysis
