@@ -1,43 +1,42 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "File.h"
+#include "zeek/file_analysis/File.h"
 
 #include <utility>
 
-#include "FileReassembler.h"
-#include "FileTimer.h"
-#include "Analyzer.h"
-#include "Manager.h"
-#include "Reporter.h"
-#include "Val.h"
-#include "Type.h"
-#include "Event.h"
-#include "RuleMatcher.h"
+#include "zeek/file_analysis/FileReassembler.h"
+#include "zeek/file_analysis/FileTimer.h"
+#include "zeek/file_analysis/Analyzer.h"
+#include "zeek/file_analysis/Manager.h"
+#include "zeek/Reporter.h"
+#include "zeek/Val.h"
+#include "zeek/Type.h"
+#include "zeek/Event.h"
+#include "zeek/RuleMatcher.h"
 
-#include "analyzer/Analyzer.h"
-#include "analyzer/Manager.h"
+#include "zeek/analyzer/Analyzer.h"
+#include "zeek/analyzer/Manager.h"
 
-#include "analyzer/extract/Extract.h"
+#include "zeek/file_analysis/analyzer/extract/Extract.h"
 
-using namespace file_analysis;
+namespace zeek::file_analysis {
 
-static Val* empty_connection_table()
+static TableValPtr empty_connection_table()
 	{
-	TypeList* tbl_index = new TypeList(conn_id);
-	tbl_index->Append(conn_id->Ref());
-	TableType* tbl_type = new TableType(tbl_index, connection_type->Ref());
-	Val* rval = new TableVal(tbl_type);
-	Unref(tbl_type);
-	return rval;
+	auto tbl_index = make_intrusive<TypeList>(id::conn_id);
+	tbl_index->Append(id::conn_id);
+	auto tbl_type = make_intrusive<TableType>(std::move(tbl_index),
+	                                          id::connection);
+	return make_intrusive<TableVal>(std::move(tbl_type));
 	}
 
-static RecordVal* get_conn_id_val(const Connection* conn)
+static RecordValPtr get_conn_id_val(const Connection* conn)
 	{
-	RecordVal* v = new RecordVal(conn_id);
-	v->Assign(0, new AddrVal(conn->OrigAddr()));
-	v->Assign(1, val_mgr->GetPort(ntohs(conn->OrigPort()), conn->ConnTransport()));
-	v->Assign(2, new AddrVal(conn->RespAddr()));
-	v->Assign(3, val_mgr->GetPort(ntohs(conn->RespPort()), conn->ConnTransport()));
+	auto v = make_intrusive<RecordVal>(id::conn_id);
+	v->Assign(0, make_intrusive<AddrVal>(conn->OrigAddr()));
+	v->Assign(1, val_mgr->Port(ntohs(conn->OrigPort()), conn->ConnTransport()));
+	v->Assign(2, make_intrusive<AddrVal>(conn->RespAddr()));
+	v->Assign(3, val_mgr->Port(ntohs(conn->RespPort()), conn->ConnTransport()));
 	return v;
 	}
 
@@ -63,27 +62,27 @@ void File::StaticInit()
 	if ( id_idx != -1 )
 		return;
 
-	id_idx = Idx("id", fa_file_type);
-	parent_id_idx = Idx("parent_id", fa_file_type);
-	source_idx = Idx("source", fa_file_type);
-	is_orig_idx = Idx("is_orig", fa_file_type);
-	conns_idx = Idx("conns", fa_file_type);
-	last_active_idx = Idx("last_active", fa_file_type);
-	seen_bytes_idx = Idx("seen_bytes", fa_file_type);
-	total_bytes_idx = Idx("total_bytes", fa_file_type);
-	missing_bytes_idx = Idx("missing_bytes", fa_file_type);
-	overflow_bytes_idx = Idx("overflow_bytes", fa_file_type);
-	timeout_interval_idx = Idx("timeout_interval", fa_file_type);
-	bof_buffer_size_idx = Idx("bof_buffer_size", fa_file_type);
-	bof_buffer_idx = Idx("bof_buffer", fa_file_type);
-	meta_mime_type_idx = Idx("mime_type", fa_metadata_type);
-	meta_mime_types_idx = Idx("mime_types", fa_metadata_type);
-	meta_inferred_idx = Idx("inferred", fa_metadata_type);
+	id_idx = Idx("id", id::fa_file);
+	parent_id_idx = Idx("parent_id", id::fa_file);
+	source_idx = Idx("source", id::fa_file);
+	is_orig_idx = Idx("is_orig", id::fa_file);
+	conns_idx = Idx("conns", id::fa_file);
+	last_active_idx = Idx("last_active", id::fa_file);
+	seen_bytes_idx = Idx("seen_bytes", id::fa_file);
+	total_bytes_idx = Idx("total_bytes", id::fa_file);
+	missing_bytes_idx = Idx("missing_bytes", id::fa_file);
+	overflow_bytes_idx = Idx("overflow_bytes", id::fa_file);
+	timeout_interval_idx = Idx("timeout_interval", id::fa_file);
+	bof_buffer_size_idx = Idx("bof_buffer_size", id::fa_file);
+	bof_buffer_idx = Idx("bof_buffer", id::fa_file);
+	meta_mime_type_idx = Idx("mime_type", id::fa_metadata);
+	meta_mime_types_idx = Idx("mime_types", id::fa_metadata);
+	meta_inferred_idx = Idx("inferred", id::fa_metadata);
 	}
 
-File::File(const string& file_id, const string& source_name, Connection* conn,
+File::File(const std::string& file_id, const std::string& source_name, Connection* conn,
            analyzer::Tag tag, bool is_orig)
-	: id(file_id), val(0), file_reassembler(0), stream_offset(0),
+	: id(file_id), val(nullptr), file_reassembler(nullptr), stream_offset(0),
 	  reassembly_max_buffer(0), did_metadata_inference(false),
 	  reassembly_enabled(false), postpone_timeout(false), done(false),
 	  analyzers(this)
@@ -92,13 +91,13 @@ File::File(const string& file_id, const string& source_name, Connection* conn,
 
 	DBG_LOG(DBG_FILE_ANALYSIS, "[%s] Creating new File object", file_id.c_str());
 
-	val = new RecordVal(fa_file_type);
-	val->Assign(id_idx, new StringVal(file_id.c_str()));
+	val = make_intrusive<RecordVal>(id::fa_file);
+	val->Assign(id_idx, make_intrusive<StringVal>(file_id.c_str()));
 	SetSource(source_name);
 
 	if ( conn )
 		{
-		val->Assign(is_orig_idx, val_mgr->GetBool(is_orig));
+		val->Assign(is_orig_idx, val_mgr->Bool(is_orig));
 		UpdateConnectionFields(conn, is_orig);
 		}
 
@@ -108,7 +107,6 @@ File::File(const string& file_id, const string& source_name, Connection* conn,
 File::~File()
 	{
 	DBG_LOG(DBG_FILE_ANALYSIS, "[%s] Destroying File object", id.c_str());
-	Unref(val);
 	delete file_reassembler;
 
 	for ( auto a : done_analyzers )
@@ -117,12 +115,12 @@ File::~File()
 
 void File::UpdateLastActivityTime()
 	{
-	val->Assign(last_active_idx, new Val(network_time, TYPE_TIME));
+	val->Assign(last_active_idx, make_intrusive<TimeVal>(run_state::network_time));
 	}
 
 double File::GetLastActivityTime() const
 	{
-	return val->Lookup(last_active_idx)->AsTime();
+	return val->GetField(last_active_idx)->AsTime();
 	}
 
 bool File::UpdateConnectionFields(Connection* conn, bool is_orig)
@@ -130,24 +128,21 @@ bool File::UpdateConnectionFields(Connection* conn, bool is_orig)
 	if ( ! conn )
 		return false;
 
-	Val* conns = val->Lookup(conns_idx);
+	Val* conns = val->GetField(conns_idx).get();
 
 	if ( ! conns )
 		{
-		conns = empty_connection_table();
-		val->Assign(conns_idx, conns);
+		auto ect = empty_connection_table();
+		conns = ect.get();
+		val->Assign(conns_idx, std::move(ect));
 		}
 
-	Val* idx = get_conn_id_val(conn);
+	auto idx = get_conn_id_val(conn);
 
-	if ( conns->AsTableVal()->Lookup(idx) )
-		{
-		Unref(idx);
+	if ( conns->AsTableVal()->FindOrDefault(idx) )
 		return false;
-		}
 
-	conns->AsTableVal()->Assign(idx, conn->BuildConnVal());
-	Unref(idx);
+	conns->AsTableVal()->Assign(std::move(idx), conn->ConnVal());
 	return true;
 	}
 
@@ -156,30 +151,26 @@ void File::RaiseFileOverNewConnection(Connection* conn, bool is_orig)
 	if ( conn && FileEventAvailable(file_over_new_connection) )
 		{
 		FileEvent(file_over_new_connection, {
-			val->Ref(),
-			conn->BuildConnVal(),
-			val_mgr->GetBool(is_orig),
+			val,
+			conn->ConnVal(),
+			val_mgr->Bool(is_orig),
 		});
 		}
 	}
 
 uint64_t File::LookupFieldDefaultCount(int idx) const
 	{
-	Val* v = val->LookupWithDefault(idx);
-	uint64_t rval = v->AsCount();
-	Unref(v);
-	return rval;
+	auto v = val->GetFieldOrDefault(idx);
+	return v->AsCount();
 	}
 
 double File::LookupFieldDefaultInterval(int idx) const
 	{
-	Val* v = val->LookupWithDefault(idx);
-	double rval = v->AsInterval();
-	Unref(v);
-	return rval;
+	auto v = val->GetFieldOrDefault(idx);
+	return v->AsInterval();
 	}
 
-int File::Idx(const string& field, const RecordType* type)
+int File::Idx(const std::string& field, const RecordType* type)
 	{
 	int rval = type->FieldOffset(field.c_str());
 
@@ -190,16 +181,16 @@ int File::Idx(const string& field, const RecordType* type)
 	return rval;
 	}
 
-string File::GetSource() const
+std::string File::GetSource() const
 	{
-	Val* v = val->Lookup(source_idx);
+	const auto& v = val->GetField(source_idx);
 
-	return v ? v->AsString()->CheckString() : string();
+	return v ? v->AsString()->CheckString() : std::string();
 	}
 
-void File::SetSource(const string& source)
+void File::SetSource(const std::string& source)
 	{
-	val->Assign(source_idx, new StringVal(source.c_str()));
+	val->Assign(source_idx, make_intrusive<StringVal>(source.c_str()));
 	}
 
 double File::GetTimeoutInterval() const
@@ -209,17 +200,21 @@ double File::GetTimeoutInterval() const
 
 void File::SetTimeoutInterval(double interval)
 	{
-	val->Assign(timeout_interval_idx, new Val(interval, TYPE_INTERVAL));
+	val->Assign(timeout_interval_idx, make_intrusive<IntervalVal>(interval));
 	}
 
 bool File::SetExtractionLimit(RecordVal* args, uint64_t bytes)
+	{ return SetExtractionLimit({NewRef{}, args}, bytes); }
+
+bool File::SetExtractionLimit(RecordValPtr args, uint64_t bytes)
 	{
-	Analyzer* a = analyzers.Find(file_mgr->GetComponentTag("EXTRACT"), args);
+	Analyzer* a = analyzers.Find(file_mgr->GetComponentTag("EXTRACT"),
+	                             std::move(args));
 
 	if ( ! a )
 		return false;
 
-	Extract* e = dynamic_cast<Extract*>(a);
+	auto* e = dynamic_cast<file_analysis::detail::Extract*>(a);
 
 	if ( ! e )
 		return false;
@@ -231,18 +226,19 @@ bool File::SetExtractionLimit(RecordVal* args, uint64_t bytes)
 void File::IncrementByteCount(uint64_t size, int field_idx)
 	{
 	uint64_t old = LookupFieldDefaultCount(field_idx);
-	val->Assign(field_idx, val_mgr->GetCount(old + size));
+	val->Assign(field_idx, val_mgr->Count(old + size));
 	}
 
 void File::SetTotalBytes(uint64_t size)
 	{
 	DBG_LOG(DBG_FILE_ANALYSIS, "[%s] Total bytes %" PRIu64, id.c_str(), size);
-	val->Assign(total_bytes_idx, val_mgr->GetCount(size));
+	val->Assign(total_bytes_idx, val_mgr->Count(size));
 	}
 
 bool File::IsComplete() const
 	{
-	Val* total = val->Lookup(total_bytes_idx);
+	const auto& total = val->GetField(total_bytes_idx);
+
 	if ( ! total )
 		return false;
 
@@ -254,10 +250,13 @@ bool File::IsComplete() const
 
 void File::ScheduleInactivityTimer() const
 	{
-	timer_mgr->Add(new FileTimer(network_time, id, GetTimeoutInterval()));
+	zeek::detail::timer_mgr->Add(new detail::FileTimer(run_state::network_time, id, GetTimeoutInterval()));
 	}
 
 bool File::AddAnalyzer(file_analysis::Tag tag, RecordVal* args)
+	{ return AddAnalyzer(tag, {NewRef{}, args}); }
+
+bool File::AddAnalyzer(file_analysis::Tag tag, RecordValPtr args)
 	{
 	DBG_LOG(DBG_FILE_ANALYSIS, "[%s] Queuing addition of %s analyzer",
 		id.c_str(), file_mgr->GetComponentName(tag).c_str());
@@ -265,15 +264,18 @@ bool File::AddAnalyzer(file_analysis::Tag tag, RecordVal* args)
 	if ( done )
 		return false;
 
-	return analyzers.QueueAdd(tag, args) != 0;
+	return analyzers.QueueAdd(tag, std::move(args)) != nullptr;
 	}
 
 bool File::RemoveAnalyzer(file_analysis::Tag tag, RecordVal* args)
+	{ return RemoveAnalyzer(tag, {NewRef{}, args}); }
+
+bool File::RemoveAnalyzer(file_analysis::Tag tag, RecordValPtr args)
 	{
 	DBG_LOG(DBG_FILE_ANALYSIS, "[%s] Queuing remove of %s analyzer",
 		id.c_str(), file_mgr->GetComponentName(tag).c_str());
 
-	return done ? false : analyzers.QueueRemove(tag, args);
+	return done ? false : analyzers.QueueRemove(tag, std::move(args));
 	}
 
 void File::EnableReassembly()
@@ -285,7 +287,7 @@ void File::DisableReassembly()
 	{
 	reassembly_enabled = false;
 	delete file_reassembler;
-	file_reassembler = 0;
+	file_reassembler = nullptr;
 	}
 
 void File::SetReassemblyBuffer(uint64_t max)
@@ -293,7 +295,7 @@ void File::SetReassemblyBuffer(uint64_t max)
 	reassembly_max_buffer = max;
 	}
 
-bool File::SetMime(const string& mime_type)
+bool File::SetMime(const std::string& mime_type)
 	{
 	if ( mime_type.empty() || bof_buffer.size != 0 || did_metadata_inference )
 		return false;
@@ -304,11 +306,11 @@ bool File::SetMime(const string& mime_type)
 	if ( ! FileEventAvailable(file_sniff) )
 		return false;
 
-	RecordVal* meta = new RecordVal(fa_metadata_type);
-	meta->Assign(meta_mime_type_idx, new StringVal(mime_type));
-	meta->Assign(meta_inferred_idx, val_mgr->GetBool(0));
+	auto meta = make_intrusive<RecordVal>(id::fa_metadata);
+	meta->Assign(meta_mime_type_idx, make_intrusive<StringVal>(mime_type));
+	meta->Assign(meta_inferred_idx, val_mgr->False());
 
-	FileEvent(file_sniff, {val->Ref(), meta});
+	FileEvent(file_sniff, {val, std::move(meta)});
 	return true;
 	}
 
@@ -316,39 +318,38 @@ void File::InferMetadata()
 	{
 	did_metadata_inference = true;
 
-	Val* bof_buffer_val = val->Lookup(bof_buffer_idx);
+	Val* bof_buffer_val = val->GetField(bof_buffer_idx).get();
 
 	if ( ! bof_buffer_val )
 		{
 		if ( bof_buffer.size == 0 )
 			return;
 
-		BroString* bs = concatenate(bof_buffer.chunks);
-		bof_buffer_val = new StringVal(bs);
-		val->Assign(bof_buffer_idx, bof_buffer_val);
+		String* bs = concatenate(bof_buffer.chunks);
+		val->Assign<StringVal>(bof_buffer_idx, bs);
+		bof_buffer_val = val->GetField(bof_buffer_idx).get();
 		}
 
 	if ( ! FileEventAvailable(file_sniff) )
 		return;
 
-	RuleMatcher::MIME_Matches matches;
+	zeek::detail::RuleMatcher::MIME_Matches matches;
 	const u_char* data = bof_buffer_val->AsString()->Bytes();
 	uint64_t len = bof_buffer_val->AsString()->Len();
-	len = min(len, LookupFieldDefaultCount(bof_buffer_size_idx));
+	len = std::min(len, LookupFieldDefaultCount(bof_buffer_size_idx));
 	file_mgr->DetectMIME(data, len, &matches);
 
-	RecordVal* meta = new RecordVal(fa_metadata_type);
+	auto meta = make_intrusive<RecordVal>(id::fa_metadata);
 
 	if ( ! matches.empty() )
 		{
-		meta->Assign(meta_mime_type_idx,
-		             new StringVal(*(matches.begin()->second.begin())));
+		meta->Assign<StringVal>(meta_mime_type_idx,
+		                        *(matches.begin()->second.begin()));
 		meta->Assign(meta_mime_types_idx,
 		             file_analysis::GenMIMEMatchesVal(matches));
 		}
 
-	FileEvent(file_sniff, {val->Ref(), meta});
-	return;
+	FileEvent(file_sniff, {val, std::move(meta)});
 	}
 
 bool File::BufferBOF(const u_char* data, uint64_t len)
@@ -358,7 +359,7 @@ bool File::BufferBOF(const u_char* data, uint64_t len)
 
 	uint64_t desired_size = LookupFieldDefaultCount(bof_buffer_size_idx);
 
-	bof_buffer.chunks.push_back(new BroString(data, len, 0));
+	bof_buffer.chunks.push_back(new String(data, len, false));
 	bof_buffer.size += len;
 
 	if ( bof_buffer.size < desired_size )
@@ -368,8 +369,8 @@ bool File::BufferBOF(const u_char* data, uint64_t len)
 
 	if ( bof_buffer.size > 0 )
 		{
-		BroString* bs = concatenate(bof_buffer.chunks);
-		val->Assign(bof_buffer_idx, new StringVal(bs));
+		String* bs = concatenate(bof_buffer.chunks);
+		val->Assign(bof_buffer_idx, make_intrusive<StringVal>(bs));
 		}
 
 	return false;
@@ -389,10 +390,10 @@ void File::DeliverStream(const u_char* data, uint64_t len)
 	        "[%s] %" PRIu64 " stream bytes in at offset %" PRIu64 "; %s [%s%s]",
 	        id.c_str(), len, stream_offset,
 	        IsComplete() ? "complete" : "incomplete",
-	        fmt_bytes((const char*) data, min((uint64_t)40, len)),
+	        util::fmt_bytes((const char*) data, std::min((uint64_t)40, len)),
 	        len > 40 ? "..." : "");
 
-	file_analysis::Analyzer* a = 0;
+	file_analysis::Analyzer* a = nullptr;
 	IterCookie* c = analyzers.InitForIteration();
 
 	while ( (a = analyzers.NextEntry(c)) )
@@ -419,7 +420,7 @@ void File::DeliverStream(const u_char* data, uint64_t len)
 								bof_buffer.chunks[i]->Len()) )
 						{
 						a->SetSkip(true);
-						analyzers.QueueRemove(a->Tag(), a->Args());
+						analyzers.QueueRemove(a->Tag(), a->GetArgs());
 						}
 					}
 
@@ -436,7 +437,7 @@ void File::DeliverStream(const u_char* data, uint64_t len)
 			if ( ! a->DeliverStream(data, len) )
 				{
 				a->SetSkip(true);
-				analyzers.QueueRemove(a->Tag(), a->Args());
+				analyzers.QueueRemove(a->Tag(), a->GetArgs());
 				}
 			}
 		}
@@ -460,15 +461,15 @@ void File::DeliverChunk(const u_char* data, uint64_t len, uint64_t offset)
 			if ( FileEventAvailable(file_reassembly_overflow) )
 				{
 				FileEvent(file_reassembly_overflow, {
-					val->Ref(),
-					val_mgr->GetCount(current_offset),
-					val_mgr->GetCount(gap_bytes),
+					val,
+					val_mgr->Count(current_offset),
+					val_mgr->Count(gap_bytes)
 				});
 				}
 			}
 
 		// Forward data to the reassembler.
-		file_reassembler->NewBlock(network_time, offset, len, data);
+		file_reassembler->NewBlock(run_state::network_time, offset, len, data);
 		}
 	else if ( stream_offset == offset )
 		{
@@ -481,7 +482,7 @@ void File::DeliverChunk(const u_char* data, uint64_t len, uint64_t offset)
 		// This is data that doesn't match the offset and the reassembler
 		// needs to be enabled.
 		file_reassembler = new FileReassembler(this, stream_offset);
-		file_reassembler->NewBlock(network_time, offset, len, data);
+		file_reassembler->NewBlock(run_state::network_time, offset, len, data);
 		}
 	else
 		{
@@ -493,10 +494,10 @@ void File::DeliverChunk(const u_char* data, uint64_t len, uint64_t offset)
 	        "[%s] %" PRIu64 " chunk bytes in at offset %" PRIu64 "; %s [%s%s]",
 	        id.c_str(), len, offset,
 	        IsComplete() ? "complete" : "incomplete",
-	        fmt_bytes((const char*) data, min((uint64_t)40, len)),
+	        util::fmt_bytes((const char*) data, std::min((uint64_t)40, len)),
 	        len > 40 ? "..." : "");
 
-	file_analysis::Analyzer* a = 0;
+	file_analysis::Analyzer* a = nullptr;
 	IterCookie* c = analyzers.InitForIteration();
 
 	while ( (a = analyzers.NextEntry(c)) )
@@ -507,7 +508,7 @@ void File::DeliverChunk(const u_char* data, uint64_t len, uint64_t offset)
 			if ( ! a->DeliverChunk(data, len, offset) )
 				{
 				a->SetSkip(true);
-				analyzers.QueueRemove(a->Tag(), a->Args());
+				analyzers.QueueRemove(a->Tag(), a->GetArgs());
 				}
 			}
 		}
@@ -560,13 +561,13 @@ void File::EndOfFile()
 
 	done = true;
 
-	file_analysis::Analyzer* a = 0;
+	file_analysis::Analyzer* a = nullptr;
 	IterCookie* c = analyzers.InitForIteration();
 
 	while ( (a = analyzers.NextEntry(c)) )
 		{
 		if ( ! a->EndOfFile() )
-			analyzers.QueueRemove(a->Tag(), a->Args());
+			analyzers.QueueRemove(a->Tag(), a->GetArgs());
 		}
 
 	FileEvent(file_state_remove);
@@ -593,23 +594,17 @@ void File::Gap(uint64_t offset, uint64_t len)
 		DeliverStream((const u_char*) "", 0);
 		}
 
-	file_analysis::Analyzer* a = 0;
+	file_analysis::Analyzer* a = nullptr;
 	IterCookie* c = analyzers.InitForIteration();
 
 	while ( (a = analyzers.NextEntry(c)) )
 		{
 		if ( ! a->Undelivered(offset, len) )
-			analyzers.QueueRemove(a->Tag(), a->Args());
+			analyzers.QueueRemove(a->Tag(), a->GetArgs());
 		}
 
 	if ( FileEventAvailable(file_gap) )
-		{
-		FileEvent(file_gap, {
-			val->Ref(),
-			val_mgr->GetCount(offset),
-			val_mgr->GetCount(len),
-		});
-		}
+		FileEvent(file_gap, {val, val_mgr->Count(offset), val_mgr->Count(len)});
 
 	analyzers.DrainModifications();
 
@@ -627,25 +622,30 @@ void File::FileEvent(EventHandlerPtr h)
 	if ( ! FileEventAvailable(h) )
 		return;
 
-	FileEvent(h, {val->Ref()});
+	FileEvent(h, Args{val});
 	}
 
-void File::FileEvent(EventHandlerPtr h, val_list* vl)
+void File::FileEvent(EventHandlerPtr h, ValPList* vl)
 	{
-	FileEvent(h, std::move(*vl));
+	FileEvent(h, val_list_to_args(*vl));
 	delete vl;
 	}
 
-void File::FileEvent(EventHandlerPtr h, val_list vl)
+void File::FileEvent(EventHandlerPtr h, ValPList vl)
 	{
-	mgr.QueueEventFast(h, std::move(vl));
+	FileEvent(h, val_list_to_args(vl));
+	}
+
+void File::FileEvent(EventHandlerPtr h, Args args)
+	{
+	event_mgr.Enqueue(h, std::move(args));
 
 	if ( h == file_new || h == file_over_new_connection ||
 	     h == file_sniff ||
 	     h == file_timeout || h == file_extraction_limit )
 		{
 		// immediate feedback is required for these events.
-		mgr.Drain();
+		event_mgr.Drain();
 		analyzers.DrainModifications();
 		}
 	}
@@ -653,5 +653,7 @@ void File::FileEvent(EventHandlerPtr h, val_list vl)
 bool File::PermitWeird(const char* name, uint64_t threshold, uint64_t rate,
                        double duration)
 	{
-	return ::PermitWeird(weird_state, name, threshold, rate, duration);
+	return zeek::detail::PermitWeird(weird_state, name, threshold, rate, duration);
 	}
+
+} // namespace zeek::file_analysis
