@@ -1,16 +1,17 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include <string>
+#include "zeek/file_analysis/analyzer/extract/Extract.h"
+
 #include <fcntl.h>
+#include <string>
 
-#include "Extract.h"
-#include "util.h"
-#include "Event.h"
-#include "file_analysis/Manager.h"
+#include "zeek/util.h"
+#include "zeek/Event.h"
+#include "zeek/file_analysis/Manager.h"
 
-using namespace file_analysis;
+namespace zeek::file_analysis::detail {
 
-Extract::Extract(zeek::RecordValPtr args, File* file,
+Extract::Extract(RecordValPtr args, file_analysis::File* file,
                  const std::string& arg_filename, uint64_t arg_limit)
     : file_analysis::Analyzer(file_mgr->GetComponentTag("EXTRACT"),
                               std::move(args), file),
@@ -22,7 +23,7 @@ Extract::Extract(zeek::RecordValPtr args, File* file,
 		{
 		fd = 0;
 		char buf[128];
-		bro_strerror_r(errno, buf, sizeof(buf));
+		util::zeek_strerror_r(errno, buf, sizeof(buf));
 		reporter->Error("cannot open %s: %s", filename.c_str(), buf);
 		}
 	}
@@ -30,11 +31,11 @@ Extract::Extract(zeek::RecordValPtr args, File* file,
 Extract::~Extract()
 	{
 	if ( fd )
-		safe_close(fd);
+		util::safe_close(fd);
 	}
 
-static const zeek::ValPtr& get_extract_field_val(const zeek::RecordValPtr& args,
-                                                 const char* name)
+static const ValPtr& get_extract_field_val(const RecordValPtr& args,
+                                           const char* name)
 	{
 	const auto& rval = args->GetField(name);
 
@@ -44,7 +45,8 @@ static const zeek::ValPtr& get_extract_field_val(const zeek::RecordValPtr& args,
 	return rval;
 	}
 
-file_analysis::Analyzer* Extract::Instantiate(zeek::RecordValPtr args, File* file)
+file_analysis::Analyzer* Extract::Instantiate(RecordValPtr args,
+                                              file_analysis::File* file)
 	{
 	const auto& fname = get_extract_field_val(args, "extract_filename");
 	const auto& limit = get_extract_field_val(args, "extract_limit");
@@ -92,12 +94,12 @@ bool Extract::DeliverStream(const u_char* data, uint64_t len)
 
 	if ( limit_exceeded && file_extraction_limit )
 		{
-		File* f = GetFile();
+		file_analysis::File* f = GetFile();
 		f->FileEvent(file_extraction_limit, {
 			f->ToVal(),
 			GetArgs(),
-			zeek::val_mgr->Count(limit),
-			zeek::val_mgr->Count(len)
+			val_mgr->Count(limit),
+			val_mgr->Count(len)
 		});
 
 		// Limit may have been modified by a BIF, re-check it.
@@ -106,7 +108,7 @@ bool Extract::DeliverStream(const u_char* data, uint64_t len)
 
 	if ( towrite > 0 )
 		{
-		safe_write(fd, reinterpret_cast<const char*>(data), towrite);
+		util::safe_write(fd, reinterpret_cast<const char*>(data), towrite);
 		depth += towrite;
 		}
 
@@ -118,10 +120,12 @@ bool Extract::Undelivered(uint64_t offset, uint64_t len)
 	if ( depth == offset )
 		{
 		char* tmp = new char[len]();
-		safe_write(fd, tmp, len);
+		util::safe_write(fd, tmp, len);
 		delete [] tmp;
 		depth += len;
 		}
 
 	return true;
 	}
+
+} // namespace zeek::file_analysis::detail
