@@ -1,10 +1,11 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "Manager.h"
-#include "ReaderFrontend.h"
-#include "ReaderBackend.h"
+#include "zeek/input/ReaderFrontend.h"
 
-namespace input {
+#include "zeek/input/Manager.h"
+#include "zeek/input/ReaderBackend.h"
+
+namespace zeek::input {
 
 class InitMessage final : public threading::InputMessage<ReaderBackend>
 {
@@ -34,13 +35,13 @@ public:
 	bool Process() override { return Object()->Update(); }
 };
 
-ReaderFrontend::ReaderFrontend(const ReaderBackend::ReaderInfo& arg_info, zeek::EnumVal* type)
+ReaderFrontend::ReaderFrontend(const ReaderBackend::ReaderInfo& arg_info, EnumVal* type)
 	{
 	disabled = initialized = false;
 	info = new ReaderBackend::ReaderInfo(arg_info);
 
 	const char* t = type->GetType()->AsEnumType()->Lookup(type->InternalInt());
-	name = copy_string(fmt("%s/%s", arg_info.source, t));
+	name = util::copy_string(util::fmt("%s/%s", arg_info.source, t));
 
 	backend = input_mgr->CreateBackend(this, type);
 	assert(backend);
@@ -97,4 +98,4 @@ const char* ReaderFrontend::Name() const
 	return name;
 	}
 
-}
+} // namespace zeek::input
