@@ -1,17 +1,15 @@
 // See the file  in the main distribution directory for copyright.
 
-#include "plugin/Plugin.h"
+#include "zeek/plugin/Plugin.h"
+#include "zeek/input/readers/ascii/Ascii.h"
 
-#include "Ascii.h"
-
-namespace plugin {
-namespace Zeek_AsciiReader {
+namespace zeek::plugin::detail::Zeek_AsciiReader {
 
 class Plugin : public zeek::plugin::Plugin {
 public:
 	zeek::plugin::Configuration Configure() override
 		{
-		AddComponent(new ::input::Component("Ascii", ::input::reader::Ascii::Instantiate));
+		AddComponent(new zeek::input::Component("Ascii", zeek::input::reader::detail::Ascii::Instantiate));
 
 		zeek::plugin::Configuration config;
 		config.name = "Zeek::AsciiReader";
@@ -20,5 +18,4 @@ public:
 		}
 } plugin;
 
-}
-}
+} // namespace zeek::plugin::detail::Zeek_AsciiReader
