@@ -1,27 +1,24 @@
-// See the file  in the main distribution directory for copyright.
-
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "Plugin.h"
+#include "zeek/plugin/Plugin.h"
 
 #include <cassert>
 
-#include "Manager.h"
-#include "Component.h"
-#include "Val.h"
+#include "zeek/plugin/Manager.h"
+#include "zeek/plugin/Component.h"
+#include "zeek/Val.h"
+#include "zeek/Desc.h"
+#include "zeek/Event.h"
+#include "zeek/Func.h"
+#include "zeek/Conn.h"
+#include "zeek/input.h"
+#include "zeek/threading/SerialTypes.h"
 
-#include "../Desc.h"
-#include "../Event.h"
-#include "../Func.h"
-#include "../Conn.h"
-#include "../input.h"
-#include "threading/SerialTypes.h"
+namespace zeek::plugin {
 
-using namespace plugin;
-
-const char* plugin::hook_name(HookType h)
+const char* hook_name(HookType h)
 {
-	static const char* hook_names[int(NUM_HOOKS) + 1] = {
+static constexpr const char* hook_names[int(NUM_HOOKS) + 1] = {
 		// Order must match that of HookType.
 		"LoadFile",
 		"CallFunction",
@@ -151,6 +148,17 @@ void HookArgument::Describe(ODesc* d) const
 			d->Add("<null>");
 		break;
 
+	case ARG_LIST:
+		if ( arg.args)
+			{
+			d->Add("(");
+			describe_vals(*arg.args, d);
+			d->Add(")");
+			}
+		else
+			d->Add("<null>");
+		break;
+
 	case VOID:
 		d->Add("<void>");
 		break;
@@ -354,7 +362,7 @@ void Plugin::RequestEvent(EventHandlerPtr handler)
 	plugin_mgr->RequestEvent(handler, this);
 	}
 
-void Plugin::RequestBroObjDtor(BroObj* obj)
+void Plugin::RequestBroObjDtor(Obj* obj)
 	{
 	plugin_mgr->RequestBroObjDtor(obj, this);
 	}
@@ -364,7 +372,28 @@ int Plugin::HookLoadFile(const LoadType type, const std::string& file, const std
 	return -1;
 	}
 
-std::pair<bool, Val*> Plugin::HookCallFunction(const Func* func, Frame *parent, val_list* args)
+std::pair<bool, ValPtr>
+Plugin::HookFunctionCall(const Func* func, zeek::detail::Frame* parent,
+                         Args* args)
+	{
+	ValPList vlargs(args->size());
+
+	for ( auto& v : *args )
+		vlargs.push_back(v.release());
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+	auto [handled, result] = HookCallFunction(func, parent, &vlargs);
+#pragma GCC diagnostic pop
+
+	for ( auto i = 0u; i < args->size(); ++i )
+		(*args)[i] = {AdoptRef{}, vlargs[i]};
+
+	return {handled, {AdoptRef{}, result}};
+	}
+
+std::pair<bool, Val*> Plugin::HookCallFunction(
+	const Func* func, zeek::detail::Frame *parent, ValPList* args)
 	{
 	std::pair<bool, Val*> result(false, NULL);
 	return result;
@@ -408,9 +437,10 @@ bool Plugin::HookLogWrite(const std::string& writer, const std::string& filter,
 	}
 
 bool Plugin::HookReporter(const std::string& prefix, const EventHandlerPtr event,
-			  const Connection* conn, const val_list* addl, bool location,
-			  const Location* location1, const Location* location2,
-			  bool time, const std::string& message)
+                          const Connection* conn, const ValPList* addl, bool location,
+                          const zeek::detail::Location* location1,
+                          const zeek::detail::Location* location2,
+                          bool time, const std::string& message)
 	{
 	return true;
 	}
@@ -475,7 +505,7 @@ void Plugin::Describe(ODesc* d) const
 
 	for ( bif_item_list::const_iterator i = items.begin(); i != items.end(); i++ )
 		{
-		const char* type = 0;
+		const char* type = nullptr;
 
 		switch ( (*i).GetType() ) {
 		case BifItem::FUNCTION:
@@ -525,3 +555,4 @@ void Plugin::Describe(ODesc* d) const
 		}
 	}
 
+} // namespace zeek::plugin
