@@ -1,32 +1,29 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "IdentifierInfo.h"
-#include "ScriptInfo.h"
-#include "utils.h"
+#include "zeek/zeekygen/IdentifierInfo.h"
+#include "zeek/zeekygen/ScriptInfo.h"
+#include "zeek/zeekygen/utils.h"
 
-#include "Desc.h"
-#include "Val.h"
-#include "Expr.h"
+#include "zeek/Desc.h"
+#include "zeek/Val.h"
+#include "zeek/Expr.h"
 
 using namespace std;
-using namespace zeekygen;
 
-IdentifierInfo::IdentifierInfo(ID* arg_id, ScriptInfo* script)
+namespace zeek::zeekygen::detail {
+
+IdentifierInfo::IdentifierInfo(zeek::detail::IDPtr arg_id, ScriptInfo* script,
+                               bool redef)
 	: Info(),
-	  comments(), id(arg_id), initial_val(), redefs(), fields(),
-	  last_field_seen(), declaring_script(script)
+	  comments(), id(std::move(arg_id)), initial_val(), redefs(), fields(),
+	  last_field_seen(), declaring_script(script), from_redef(redef)
 	{
-	Ref(id);
-
-	if ( id->ID_Val() && (id->IsOption() || id->IsRedefinable()) )
-		initial_val = id->ID_Val()->Clone();
+	if ( id->GetVal() && (id->IsOption() || id->IsRedefinable()) )
+		initial_val = id->GetVal()->Clone();
 	}
 
 IdentifierInfo::~IdentifierInfo()
 	{
-	Unref(id);
-	Unref(initial_val);
-
 	for ( redef_list::const_iterator it = redefs.begin(); it != redefs.end();
 	      ++it )
 		delete *it;
@@ -36,22 +33,32 @@ IdentifierInfo::~IdentifierInfo()
 		delete it->second;
 	}
 
-void IdentifierInfo::AddRedef(const string& script, init_class ic,
-                              Expr* init_expr, const vector<string>& comments)
+void IdentifierInfo::AddRedef(const string& script, zeek::detail::InitClass ic,
+                              zeek::detail::ExprPtr init_expr, const vector<string>& comments)
 	{
-	Redefinition* redef = new Redefinition(script, ic, init_expr, comments);
+	Redefinition* redef = new Redefinition(script, ic, std::move(init_expr), comments);
 	redefs.push_back(redef);
 	}
 
 void IdentifierInfo::AddRecordField(const TypeDecl* field,
-				    const string& script,
-				    vector<string>& comments)
+                                    const string& script,
+                                    vector<string>& comments,
+                                    bool from_redef)
 	{
 	RecordField* rf = new RecordField();
 	rf->field = new TypeDecl(*field);
 	rf->from_script = script;
 	rf->comments = comments;
-	fields[rf->field->id] = rf;
+	rf->from_redef = from_redef;
+
+	auto [it, inserted] = fields.emplace(rf->field->id, rf);
+
+	if ( ! inserted )
+		{
+		delete it->second;
+		it->second = rf;
+		}
+
 	last_field_seen = rf;
 	}
 
@@ -95,6 +102,16 @@ string IdentifierInfo::GetDeclaringScriptForField(const string& field) const
 	return it->second->from_script;
 	}
 
+bool IdentifierInfo::FieldIsFromRedef(const std::string& field) const
+	{
+	auto it = fields.find(field);
+
+	if ( it == fields.end() )
+		return false;
+
+	return it->second->from_redef;
+	}
+
 string IdentifierInfo::DoReStructuredText(bool roles_only) const
 	{
 	ODesc d;
@@ -113,11 +130,11 @@ string IdentifierInfo::DoReStructuredText(bool roles_only) const
 		if ( i > 0 )
 			d.NL();
 
-		if ( IsFunc(id->Type()->Tag()) )
+		if ( IsFunc(id->GetType()->Tag()) )
 			{
 			string s = comments[i];
 
-			if ( zeekygen::prettify_params(s) )
+			if ( prettify_params(s) )
 				d.NL();
 
 			d.Add(s.c_str());
@@ -136,52 +153,22 @@ time_t IdentifierInfo::DoGetModificationTime() const
 	return declaring_script->GetModificationTime();
 	}
 
-IdentifierInfo::Redefinition::Redefinition(
-                       std::string arg_script,
-                       init_class arg_ic,
-                       Expr* arg_expr,
-                       std::vector<std::string> arg_comments)
-			: from_script(std::move(arg_script)),
-			  ic(arg_ic),
-			  init_expr(arg_expr ? arg_expr->Ref() : nullptr),
-			  comments(std::move(arg_comments))
+IdentifierInfo::Redefinition::Redefinition(std::string arg_script,
+                                           zeek::detail::InitClass arg_ic,
+                                           zeek::detail::ExprPtr arg_expr,
+                                           std::vector<std::string> arg_comments)
+	: from_script(std::move(arg_script)),
+	  ic(arg_ic),
+	  init_expr(std::move(arg_expr)),
+	  comments(std::move(arg_comments))
 	{
 	}
 
-IdentifierInfo::Redefinition::Redefinition(const IdentifierInfo::Redefinition& other)
-	{
-	from_script = other.from_script;
-	ic = other.ic;
-	init_expr = other.init_expr;
-	comments = other.comments;
-
-	if ( init_expr )
-		init_expr->Ref();
-	}
-
-IdentifierInfo::Redefinition&
-IdentifierInfo::Redefinition::operator=(const IdentifierInfo::Redefinition& other)
-	{
-	if ( &other == this )
-		return *this;
-
-	from_script = other.from_script;
-	ic = other.ic;
-	init_expr = other.init_expr;
-	comments = other.comments;
-
-	if ( init_expr )
-		init_expr->Ref();
-
-	return *this;
-	}
-
-IdentifierInfo::Redefinition::~Redefinition()
-	{
-	Unref(init_expr);
-	}
+IdentifierInfo::Redefinition::~Redefinition() = default;
 
 IdentifierInfo::RecordField::~RecordField()
 	{
 	delete field;
 	}
+
+} // namespace zeek::zeekygen::detail
